import React, { Component } from 'react';
import { BackHandler, ToastAndroid, Alert } from 'react-native';
import {
  StyleSheet,
  Text,
  View,
  TouchableOpacity
} from 'react-native';
import { IMAGE_TO_TEXT } from './../ServiceUrl';
import { Container, Header, Content, Icon, Button } from 'native-base';
import { MaterialDialog } from 'react-native-material-dialog';
import { RNCamera } from 'react-native-camera';
import { scheduleLocalNotification, appointmentNotification, futch } from './../Utils';
import { connect } from 'react-redux'
import { reminderCreate } from './../actions'
import ReminderDialogForm from './../components/ReminderDialogForm';
import moment from 'moment';
import realm from './../Database/';

class AppCamera extends Component {

  constructor(props) {
    super(props)
    this.state = {
      morningTime: "",
      afternoonTime: "",
      eveningTime: "",
      nightTime: "",
      addItemVisible: true,
      visible: false,
      imageToText: "",
      uploadProgress: "0",
      addReminder: false
    }
  }

  componentWillMount() {
    let timePeriod = realm.objects('TimePeriod')
    var morningTime = timePeriod[0].morning
    var afternoonTime = timePeriod[0].afternoon
    var eveningTime = timePeriod[0].evening
    var nightTime = timePeriod[0].night

    this.setState({ morningTime, afternoonTime, eveningTime, nightTime })
  }

  render() {
    return (
      <Container style={styles.container}>
        <RNCamera
          ref={ref => {
            this.camera = ref;
          }}
          style={styles.preview}
          type={RNCamera.Constants.Type.back}
          fixOrientation={true}
          permissionDialogTitle={'Permission to use camera'}
          permissionDialogMessage={'We need your permission to use your camera phone'}
        />
        <View style={{ flex: 0, flexDirection: 'row', justifyContent: 'center', }}>
          <TouchableOpacity
            onPress={this.takePicture.bind(this)}
            style={styles.capture}
          >
            <Text style={{ fontSize: 14 }}> SNAP </Text>
          </TouchableOpacity>
        </View>
        <MaterialDialog
          title="Add Reminder"
          visible={this.state.visible}
          onOk={() => this.setState({ visible: false, imageToText: '', uploadProgress: '0' })}
          onCancel={() => this.setState({ visible: false, imageToText: '', uploadProgress: '0' })}>
          <ReminderDialogForm
            uploadProgress={this.state.uploadProgress}
            imageToText={this.state.imageToText}
          />

        </MaterialDialog>
      </Container >
    );
  }

  takePicture = async function () {
    this.setState({ visible: true })

    if (this.camera) {
      const options = { quality: 0.5, base64: true };
      const data = await this.camera.takePictureAsync(options)
      const image = new FormData()
      image.append('image', {
        uri: data.uri,
        type: 'imge/jpeg',
        name: 'image'
      })

      futch(IMAGE_TO_TEXT, {
        method: 'post',
        body: image
      }, (progressEvent) => {
        const progress = (progressEvent.loaded / progressEvent.total) * 100;
        this.setState({ uploadProgress: parseInt(progress).toString() })
      }).then(res => {
        this.setState({ imageToText: JSON.parse(res._response) })
      }).catch(err => {
        this.setState({ imageToText: JSON.stringify(err) })
      })

    }
  }

  // _onBarCodeRead(data, type) {
  //   if (data.type == 'QR_CODE') {
  //     var tmpData = JSON.parse(decodeURI(data.data))
  //     switch (tmpData.type) {
  //       case "medicine":
  //         if (this.state.addItemVisible) {
  //           this._addMedicine(tmpData)
  //           this.setState({ addItemVisible: false })
  //         }
  //         break;
  //       case "appointment":
  //         if (this.state.addItemVisible) {
  //           this._addAppointment(tmpData)
  //           this.setState({ addItemVisible: false })
  //         }
  //         break;
  //     }
  //   }
  // }

}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: 'column',
    backgroundColor: 'black'
  },
  preview: {
    flex: 1,
    justifyContent: 'flex-end',
    alignItems: 'center'
  },
  capture: {
    flex: 0,
    backgroundColor: '#fff',
    borderRadius: 5,
    padding: 15,
    paddingHorizontal: 20,
    alignSelf: 'center',
    margin: 20
  }
});

export default connect(null, { reminderCreate })(AppCamera);